@@ -2,7 +2,7 @@
  * appres.h : External defs for files needing the application
  *	resources.
  *
- * George Ferguson, ferguson@cs.rochester.edu, 21 Aug 1991.
+ * George Ferguson, ferguson@cs.rochester.edu, 12 Sep 1991.
  *
  */
 
@@ -21,6 +21,8 @@ typedef struct {
     int		timeout;
     int		retries;
     int		niceLevel;
+    String	ftpDir;
+    String	ftpType;
     int		debugLevel;
     String	settingsWidgets;
 } AppResources;
